==> xcsoar-6.5.3.tar.bz2: xcsoar-6.5.3/src/Widget/ListWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LIST_WIDGET_HPP
#define XCSOAR_LIST_WIDGET_HPP

#include "WindowWidget.hpp"
#include "Form/List.hpp"

class Window;

/**
 * A wrapper that turns a #ListControl into a #Widget.  Call
 * CreateList() in your implementation to create and set the
 * #ListControl.  It is not deleted automatically; call
 * WindowWidget::DeleteWindow() to do that at your choice.
 */
class ListWidget : public WindowWidget, protected ListControl::Handler {
protected:
  const ListControl &GetList() const {
    return *(const ListControl *)GetWindow();
  }

  ListControl &GetList() {
    return *(ListControl *)GetWindow();
  }

  ListControl &CreateList(ContainerWindow &parent, const DialogLook &look,
                          const PixelRect &rc, UPixelScalar row_height);

public:
  virtual PixelSize GetMinimumSize() const override;
  virtual PixelSize GetMaximumSize() const override;
};

#endif

==> xcsoar-6.7.3.tar.bz2: xcsoar-6.7.3/src/Widget/ListWidget.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_LIST_WIDGET_HPP
#define XCSOAR_LIST_WIDGET_HPP

#include "WindowWidget.hpp"
#include "Form/List.hpp"

class Window;

/**
 * A wrapper that turns a #ListControl into a #Widget.  Call
 * CreateList() in your implementation to create and set the
 * #ListControl.  It is not deleted automatically; call
 * WindowWidget::DeleteWindow() to do that at your choice.
 */
class ListWidget
  : public WindowWidget, protected ListItemRenderer,
    protected ListCursorHandler {
protected:
  const ListControl &GetList() const {
    return (const ListControl &)GetWindow();
  }

  ListControl &GetList() {
    return (ListControl &)GetWindow();
  }

  ListControl &CreateList(ContainerWindow &parent, const DialogLook &look,
                          const PixelRect &rc, UPixelScalar row_height);

public:
  virtual PixelSize GetMinimumSize() const override;
  virtual PixelSize GetMaximumSize() const override;
};

#endif
